@@ -1,7 +1,7 @@
 package App::swcat;
 
 our $DATE = '2018-10-18'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -105,6 +105,12 @@ our %argopt0_softwares_or_patterns = (
     },
 );
 
+our %arg0_softwares_or_patterns;
+$arg0_softwares_or_patterns{softwares_or_patterns} = {
+    %{$argopt0_softwares_or_patterns{softwares_or_patterns}},
+    req => 1,
+};
+
 our %argopt_arch = (
     arch => {
         schema => ['software::arch*'],
@@ -436,7 +442,7 @@ App::swcat - Software catalog
 
 =head1 VERSION
 
-This document describes version 0.004 of App::swcat (from Perl distribution App-swcat), released on 2018-10-18.
+This document describes version 0.005 of App::swcat (from Perl distribution App-swcat), released on 2018-10-18.
 
 =head1 SYNOPSIS
 
